import { XAxisStrategy, YAxisStrategy } from './axis.service';
export class Axis {
    constructor() {
        this.dimension = 'x';
        this.show = true;
        this.ticks = true;
    }
    componentDidLoad() {
        this.setStrategy();
        const axisConfig = {
            showAxis: this.show,
            showTicks: this.ticks,
            formattingOptions: {
                locale: this.locale || 'en-US',
                language: this.language || 'en',
                currency: this.currency || 'USD'
            }
        };
        if (this.type) {
            axisConfig.labelType = this.type;
        }
        this.service.emit(axisConfig);
    }
    async init(svg, dims, data, axisConfigs, minMax, primarySeries, y) {
        return Promise.resolve(this.service.addAxis(svg, dims, data, axisConfigs, minMax, primarySeries, y));
    }
    setStrategy() {
        this.service = (this.dimension === 'x') ? new XAxisStrategy(this.anjXAxisDidLoad) : new YAxisStrategy(this.anjYAxisDidLoad);
    }
    static get is() { return "anj-axis"; }
    static get properties() { return {
        "currency": {
            "type": String,
            "attr": "currency"
        },
        "dimension": {
            "type": String,
            "attr": "dimension",
            "reflectToAttr": true
        },
        "element": {
            "elementRef": true
        },
        "init": {
            "method": true
        },
        "language": {
            "type": String,
            "attr": "language"
        },
        "locale": {
            "type": String,
            "attr": "locale"
        },
        "show": {
            "type": Boolean,
            "attr": "show"
        },
        "ticks": {
            "type": Boolean,
            "attr": "ticks"
        },
        "type": {
            "type": String,
            "attr": "type"
        }
    }; }
    static get events() { return [{
            "name": "anjYAxisDidLoad",
            "method": "anjYAxisDidLoad",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }, {
            "name": "anjXAxisDidLoad",
            "method": "anjXAxisDidLoad",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
}
