import { ChartD3Service } from '../../services/chart.d3.service';
import { SeriesType } from '../../interfaces/SeriesType';
export class ChartEvents {
    constructor(primarySeries, anjHover, chartService, popover) {
        this.primarySeries = primarySeries;
        this.anjHover = anjHover;
        this.chartService = chartService;
        this.popover = popover;
    }
    anjHoverHandler(svg, data, x, axisConfigs, seriesMeta) {
        const targetData = this.chartService.getTargetingData(data);
        const dataIndex = ChartD3Service.getIndexOfClosestPoint(x, targetData);
        if (this.activeIndex !== dataIndex) {
            this.setPopoverData(dataIndex, data, axisConfigs, seriesMeta);
            this.popoverTimer = window.setTimeout(() => {
                this.displayPopover(svg, this.activeIndex, true);
            }, ChartEvents.popoverDebounceLength);
        }
    }
    anjColumnHoverHandler(targetEl, data, dataIndex, axisConfigs, seriesMeta) {
        window.clearTimeout(this.popoverTimer);
        this.setPopoverData(dataIndex, [data], axisConfigs, seriesMeta);
        this.displayPopover(targetEl);
    }
    anjStackedHoverHandler(svg, data, dataIndex, axisConfigs, seriesMeta) {
        window.clearTimeout(this.popoverTimer);
        if (this.activeIndex !== dataIndex) {
            this.setPopoverData(dataIndex, data, axisConfigs, seriesMeta);
            this.displayPopover(svg, this.activeIndex, true);
        }
    }
    anjEndHoverHandler(svg) {
        switch (this.primarySeries) {
            case SeriesType.Line:
                window.clearTimeout(this.popoverTimer);
                this.hidePopover(svg);
            default:
                this.popoverTimer = window.setTimeout(() => {
                    this.hidePopover(svg);
                }, ChartEvents.popoverDebounceLength);
        }
    }
    displayPopover(svg, activeIndex, focus) {
        const popoverEl = (!isNaN(activeIndex)) ? this.chartService.getPopoverEl(svg, activeIndex) : svg;
        this.display(popoverEl);
        if (focus) {
            ChartD3Service.showFocus(svg, activeIndex);
        }
    }
    async display(target) {
        if (!target) {
            return;
        }
        const popper = await this.popover.popper();
        if (popper) {
            popper.reference = target;
            popper.scheduleUpdate();
        }
        else {
            this.popover.open(target);
        }
    }
    hidePopover(svg) {
        this.activeIndex = null;
        this.popover.close();
        ChartD3Service.hideFocus(svg);
    }
    setPopoverData(dataIndex, data, axisConfigs, seriesMeta) {
        this.activeIndex = dataIndex;
        const seriesStyle = this.chartService.getPopoverSeriesStyle();
        const activeData = { data, axisConfigs, activeIndex: this.activeIndex, seriesStyle, seriesMeta };
        this.anjHover.emit(activeData);
    }
}
ChartEvents.popoverDebounceLength = 150;
