import { ChartDataService } from '../../services/chart.data.service';
import { SeriesStyle } from '../../interfaces/SeriesStyle';
export class PopoverContentSingle {
    activeDataHandler(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Single) {
            return;
        }
        const x = newValue.data[0][newValue.activeIndex].x;
        const y = newValue.data[0][newValue.activeIndex].y;
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data[0]);
            this.delta = PopoverContentSingle.getDelta(newValue);
        }
        this.xDisplayValue = ChartDataService.xFormatter(this.period, newValue.axisConfigs.x, x);
        this.yDisplayValue = ChartDataService.yFormatter(newValue.axisConfigs.y, y);
    }
    componentDidLoad() {
        this.anjPopoverDidLoad.emit();
    }
    async onDeltaLoaded() {
        this.debounceRender();
    }
    debounceRender() {
        window.clearTimeout(this.renderTimer);
        this.renderTimer = window.setTimeout(async () => {
            this.render();
        }, 250);
    }
    static getDelta(activeData) {
        if (activeData.activeIndex === 0) {
            return undefined;
        }
        const prevY = parseInt(activeData.data[0][activeData.activeIndex - 1].y, 10);
        const y = parseInt(activeData.data[0][activeData.activeIndex].y, 10);
        return Math.round((1 - (y / prevY)) * -100);
    }
    render() {
        return (this.activeData) ? [
            h("div", null,
                h("div", null, this.xDisplayValue),
                h("div", { class: "anj-value" }, this.yDisplayValue),
                h("anj-delta", { delta: this.delta, period: this.period }))
        ] : undefined;
    }
    static get is() { return "anj-popover-content-single"; }
    static get properties() { return {
        "activeData": {
            "type": "Any",
            "attr": "active-data",
            "watchCallbacks": ["activeDataHandler"]
        }
    }; }
    static get events() { return [{
            "name": "anjPopoverDidLoad",
            "method": "anjPopoverDidLoad",
            "bubbles": true,
            "cancelable": true,
            "composed": true
        }]; }
    static get listeners() { return [{
            "name": "anjDeltaDidLoad",
            "method": "onDeltaLoaded"
        }]; }
    static get style() { return "/**style-placeholder:anj-popover-content-single:**/"; }
}
